/**
 * Dragon - SOA Governance Platform.
 * Copyright (c) 2008 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * ExecutionEnvironmentManager.java
 * -------------------------------------------------------------------------
 */

package org.ow2.dragon.connection.api.service;

import java.util.List;

import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;

import org.ow2.dragon.connection.api.to.Endpoint;
import org.ow2.dragon.connection.api.to.ExecutionEnvironment;

/**
 * An Execution Environment is a software that could expose services. Examples
 * of execution environments: Application Server (JBoss, Jonas, WebSphere,
 * etc.), ESB (PEtALS, ServiceMix, OpenESB, JBoss ESB, etc.). <br/>
 * An Execution Environment Manager is an agent that supervises Execution
 * Environment: properties, messages exchanged, state, etc. <br/>
 * A Processor is a hardware hosting Execution Environments: MainFrame, Server,
 * etc. <br/>
 * A Federation is group of linked Execution Environments. Examples of
 * Federation: Federated or Distributed ESB, Grid, etc.
 * 
 * @author ofabre - eBM Websourcing
 * 
 */
@WebService(targetNamespace = "http://service.api.connection.dragon.ow2.org/")
@SOAPBinding(style = SOAPBinding.Style.DOCUMENT, use = SOAPBinding.Use.LITERAL)
public interface ExecutionEnvironmentManager {

    /**
     * Returns the list of all execution environments managed by this execution
     * environment manager.
     * 
     * @return a list of managed {@link ExecutionEnvironment}, must be non null,
     *         can be empty.
     */
    @WebResult(targetNamespace = "http://service.api.connection.dragon.ow2.org/", name="ExecutionEnvironment")
    List<ExecutionEnvironment> getManagedExecutionEnvironments();

    /**
     * Return the list of service endpoints hosted by the given Execution
     * Environment.
     * 
     * @param managedExecEnvName
     *            the name that identifies a unique Execution Environment
     * @return a list of hosted {@link Endpoint}, must be non null, can be
     *         empty.
     */
    @WebResult(targetNamespace = "http://service.api.connection.dragon.ow2.org/", name="Endpoint")
    List<Endpoint> getHostedEndpointsOnExecEnv(String managedExecEnvName);

    /**
     * Return the list of service endpoints hosted by the given Processor.
     * 
     * @param managedProcessorName
     *            the name that identifies a unique Processor
     * @return a list of hosted {@link Endpoint}, must be non null, can be
     *         empty.
     */
    @WebResult(targetNamespace = "http://service.api.connection.dragon.ow2.org/", name="Endpoint")
    List<Endpoint> getHostedEndpointsOnProcessor(String managedProcessorName);

    /**
     * Returns the list of all execution environments members of the given
     * federation.
     * 
     * @param managedFederationName
     *            the name that identifies a unique Federation
     * @return a list of members {@link ExecutionEnvironment}, must be non null,
     *         can be empty
     */
    @WebResult(targetNamespace = "http://service.api.connection.dragon.ow2.org/", name="ExecutionEnvironment")
    List<ExecutionEnvironment> getFederationMembers(String managedFederationName);

    /**
     * Returns Execution Environment Manager properties: name, etc.
     * 
     * @return a {@link ExecutionEnvironmentManager} instance representation,
     *         filled with its properties
     */
    @WebResult(targetNamespace = "http://service.api.connection.dragon.ow2.org/", name="ExecutionEnvironmentManager")
    org.ow2.dragon.connection.api.to.ExecutionEnvironmentManager getProperties();

}
